@@ -7,7 +7,7 @@ use File::Basename;
 use File::Spec;
 use File::Glob;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 # some class data
 our $Theme = 'foo'; # default theme
@@ -61,7 +61,7 @@ sub new {
     $theme = $Theme unless $theme; # same default everywhere
 
     # defer croaking until name() is actually called
-    bless { theme => $theme, args => \@args, meta => {} }, $class;
+    bless { theme => $theme, args => { @args }, meta => {} }, $class;
 }
 
 # CLASS METHODS
@@ -158,7 +158,7 @@ sub name {
             $META{$theme} = 1; # loaded
         }
         $self->{meta}{$theme} =
-          "Acme::MetaSyntactic::$theme"->new( @{ $self->{args} } );
+          "Acme::MetaSyntactic::$theme"->new( %{ $self->{args} } );
     }
 
     $self->{meta}{$theme}->name( $count );
